#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CustomMetric import CustomMetric


class AlipayCommerceDataCustommetricSyncModel(object):

    def __init__(self):
        self._metric_data = None
        self._namespace = None

    @property
    def metric_data(self):
        return self._metric_data

    @metric_data.setter
    def metric_data(self, value):
        if isinstance(value, list):
            self._metric_data = list()
            for i in value:
                if isinstance(i, CustomMetric):
                    self._metric_data.append(i)
                else:
                    self._metric_data.append(CustomMetric.from_alipay_dict(i))
    @property
    def namespace(self):
        return self._namespace

    @namespace.setter
    def namespace(self, value):
        self._namespace = value


    def to_alipay_dict(self):
        params = dict()
        if self.metric_data:
            if isinstance(self.metric_data, list):
                for i in range(0, len(self.metric_data)):
                    element = self.metric_data[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.metric_data[i] = element.to_alipay_dict()
            if hasattr(self.metric_data, 'to_alipay_dict'):
                params['metric_data'] = self.metric_data.to_alipay_dict()
            else:
                params['metric_data'] = self.metric_data
        if self.namespace:
            if hasattr(self.namespace, 'to_alipay_dict'):
                params['namespace'] = self.namespace.to_alipay_dict()
            else:
                params['namespace'] = self.namespace
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceDataCustommetricSyncModel()
        if 'metric_data' in d:
            o.metric_data = d['metric_data']
        if 'namespace' in d:
            o.namespace = d['namespace']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SettlementBillCreateOrder import SettlementBillCreateOrder


class AlipayBossFncSettleSettlementbillCreateModel(object):

    def __init__(self):
        self._settlement_bill_create_order = None

    @property
    def settlement_bill_create_order(self):
        return self._settlement_bill_create_order

    @settlement_bill_create_order.setter
    def settlement_bill_create_order(self, value):
        if isinstance(value, list):
            self._settlement_bill_create_order = list()
            for i in value:
                if isinstance(i, SettlementBillCreateOrder):
                    self._settlement_bill_create_order.append(i)
                else:
                    self._settlement_bill_create_order.append(SettlementBillCreateOrder.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.settlement_bill_create_order:
            if isinstance(self.settlement_bill_create_order, list):
                for i in range(0, len(self.settlement_bill_create_order)):
                    element = self.settlement_bill_create_order[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.settlement_bill_create_order[i] = element.to_alipay_dict()
            if hasattr(self.settlement_bill_create_order, 'to_alipay_dict'):
                params['settlement_bill_create_order'] = self.settlement_bill_create_order.to_alipay_dict()
            else:
                params['settlement_bill_create_order'] = self.settlement_bill_create_order
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncSettleSettlementbillCreateModel()
        if 'settlement_bill_create_order' in d:
            o.settlement_bill_create_order = d['settlement_bill_create_order']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AgentScheduleLog import AgentScheduleLog


class AlipayIserviceCcmAgentSchedulelogQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCcmAgentSchedulelogQueryResponse, self).__init__()
        self._agent_schedule_logs = None
        self._page_num = None
        self._page_size = None
        self._total_count = None

    @property
    def agent_schedule_logs(self):
        return self._agent_schedule_logs

    @agent_schedule_logs.setter
    def agent_schedule_logs(self, value):
        if isinstance(value, AgentScheduleLog):
            self._agent_schedule_logs = value
        else:
            self._agent_schedule_logs = AgentScheduleLog.from_alipay_dict(value)
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCcmAgentSchedulelogQueryResponse, self).parse_response_content(response_content)
        if 'agent_schedule_logs' in response:
            self.agent_schedule_logs = response['agent_schedule_logs']
        if 'page_num' in response:
            self.page_num = response['page_num']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total_count' in response:
            self.total_count = response['total_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AssetParams(object):

    def __init__(self):
        self._asset_type = None
        self._card_no = None
        self._inst_id = None

    @property
    def asset_type(self):
        return self._asset_type

    @asset_type.setter
    def asset_type(self, value):
        self._asset_type = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_type:
            if hasattr(self.asset_type, 'to_alipay_dict'):
                params['asset_type'] = self.asset_type.to_alipay_dict()
            else:
                params['asset_type'] = self.asset_type
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AssetParams()
        if 'asset_type' in d:
            o.asset_type = d['asset_type']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TemplateRightsContentDTO(object):

    def __init__(self):
        self._detail = None
        self._logo_id = None
        self._title = None

    @property
    def detail(self):
        return self._detail

    @detail.setter
    def detail(self, value):
        self._detail = value
    @property
    def logo_id(self):
        return self._logo_id

    @logo_id.setter
    def logo_id(self, value):
        self._logo_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.detail:
            if hasattr(self.detail, 'to_alipay_dict'):
                params['detail'] = self.detail.to_alipay_dict()
            else:
                params['detail'] = self.detail
        if self.logo_id:
            if hasattr(self.logo_id, 'to_alipay_dict'):
                params['logo_id'] = self.logo_id.to_alipay_dict()
            else:
                params['logo_id'] = self.logo_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TemplateRightsContentDTO()
        if 'detail' in d:
            o.detail = d['detail']
        if 'logo_id' in d:
            o.logo_id = d['logo_id']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IntelligentGuideTradeDetail import IntelligentGuideTradeDetail


class IntelligentGuideTradeInfo(object):

    def __init__(self):
        self._shop_id = None
        self._shop_name = None
        self._trade_details = None

    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def trade_details(self):
        return self._trade_details

    @trade_details.setter
    def trade_details(self, value):
        if isinstance(value, list):
            self._trade_details = list()
            for i in value:
                if isinstance(i, IntelligentGuideTradeDetail):
                    self._trade_details.append(i)
                else:
                    self._trade_details.append(IntelligentGuideTradeDetail.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.trade_details:
            if isinstance(self.trade_details, list):
                for i in range(0, len(self.trade_details)):
                    element = self.trade_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.trade_details[i] = element.to_alipay_dict()
            if hasattr(self.trade_details, 'to_alipay_dict'):
                params['trade_details'] = self.trade_details.to_alipay_dict()
            else:
                params['trade_details'] = self.trade_details
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IntelligentGuideTradeInfo()
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'trade_details' in d:
            o.trade_details = d['trade_details']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbdishMaterialInfo(object):

    def __init__(self):
        self._add_price = None
        self._create_user = None
        self._ext_info = None
        self._material_desc = None
        self._material_id = None
        self._material_img = None
        self._material_name = None
        self._material_type = None
        self._max_num = None
        self._merchant_id = None
        self._out_material_id = None
        self._public_id = None
        self._unit_id = None
        self._update_user = None

    @property
    def add_price(self):
        return self._add_price

    @add_price.setter
    def add_price(self, value):
        self._add_price = value
    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def material_desc(self):
        return self._material_desc

    @material_desc.setter
    def material_desc(self, value):
        self._material_desc = value
    @property
    def material_id(self):
        return self._material_id

    @material_id.setter
    def material_id(self, value):
        self._material_id = value
    @property
    def material_img(self):
        return self._material_img

    @material_img.setter
    def material_img(self, value):
        self._material_img = value
    @property
    def material_name(self):
        return self._material_name

    @material_name.setter
    def material_name(self, value):
        self._material_name = value
    @property
    def material_type(self):
        return self._material_type

    @material_type.setter
    def material_type(self, value):
        self._material_type = value
    @property
    def max_num(self):
        return self._max_num

    @max_num.setter
    def max_num(self, value):
        self._max_num = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def out_material_id(self):
        return self._out_material_id

    @out_material_id.setter
    def out_material_id(self, value):
        self._out_material_id = value
    @property
    def public_id(self):
        return self._public_id

    @public_id.setter
    def public_id(self, value):
        self._public_id = value
    @property
    def unit_id(self):
        return self._unit_id

    @unit_id.setter
    def unit_id(self, value):
        self._unit_id = value
    @property
    def update_user(self):
        return self._update_user

    @update_user.setter
    def update_user(self, value):
        self._update_user = value


    def to_alipay_dict(self):
        params = dict()
        if self.add_price:
            if hasattr(self.add_price, 'to_alipay_dict'):
                params['add_price'] = self.add_price.to_alipay_dict()
            else:
                params['add_price'] = self.add_price
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.material_desc:
            if hasattr(self.material_desc, 'to_alipay_dict'):
                params['material_desc'] = self.material_desc.to_alipay_dict()
            else:
                params['material_desc'] = self.material_desc
        if self.material_id:
            if hasattr(self.material_id, 'to_alipay_dict'):
                params['material_id'] = self.material_id.to_alipay_dict()
            else:
                params['material_id'] = self.material_id
        if self.material_img:
            if hasattr(self.material_img, 'to_alipay_dict'):
                params['material_img'] = self.material_img.to_alipay_dict()
            else:
                params['material_img'] = self.material_img
        if self.material_name:
            if hasattr(self.material_name, 'to_alipay_dict'):
                params['material_name'] = self.material_name.to_alipay_dict()
            else:
                params['material_name'] = self.material_name
        if self.material_type:
            if hasattr(self.material_type, 'to_alipay_dict'):
                params['material_type'] = self.material_type.to_alipay_dict()
            else:
                params['material_type'] = self.material_type
        if self.max_num:
            if hasattr(self.max_num, 'to_alipay_dict'):
                params['max_num'] = self.max_num.to_alipay_dict()
            else:
                params['max_num'] = self.max_num
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.out_material_id:
            if hasattr(self.out_material_id, 'to_alipay_dict'):
                params['out_material_id'] = self.out_material_id.to_alipay_dict()
            else:
                params['out_material_id'] = self.out_material_id
        if self.public_id:
            if hasattr(self.public_id, 'to_alipay_dict'):
                params['public_id'] = self.public_id.to_alipay_dict()
            else:
                params['public_id'] = self.public_id
        if self.unit_id:
            if hasattr(self.unit_id, 'to_alipay_dict'):
                params['unit_id'] = self.unit_id.to_alipay_dict()
            else:
                params['unit_id'] = self.unit_id
        if self.update_user:
            if hasattr(self.update_user, 'to_alipay_dict'):
                params['update_user'] = self.update_user.to_alipay_dict()
            else:
                params['update_user'] = self.update_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishMaterialInfo()
        if 'add_price' in d:
            o.add_price = d['add_price']
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'material_desc' in d:
            o.material_desc = d['material_desc']
        if 'material_id' in d:
            o.material_id = d['material_id']
        if 'material_img' in d:
            o.material_img = d['material_img']
        if 'material_name' in d:
            o.material_name = d['material_name']
        if 'material_type' in d:
            o.material_type = d['material_type']
        if 'max_num' in d:
            o.max_num = d['max_num']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'out_material_id' in d:
            o.out_material_id = d['out_material_id']
        if 'public_id' in d:
            o.public_id = d['public_id']
        if 'unit_id' in d:
            o.unit_id = d['unit_id']
        if 'update_user' in d:
            o.update_user = d['update_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditGuaranteeContractSignResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditGuaranteeContractSignResponse, self).__init__()
        self._ar_no = None

    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditGuaranteeContractSignResponse, self).parse_response_content(response_content)
        if 'ar_no' in response:
            self.ar_no = response['ar_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenPublicPersonalizedExtensionDeleteModel(object):

    def __init__(self):
        self._extension_key = None

    @property
    def extension_key(self):
        return self._extension_key

    @extension_key.setter
    def extension_key(self, value):
        self._extension_key = value


    def to_alipay_dict(self):
        params = dict()
        if self.extension_key:
            if hasattr(self.extension_key, 'to_alipay_dict'):
                params['extension_key'] = self.extension_key.to_alipay_dict()
            else:
                params['extension_key'] = self.extension_key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicPersonalizedExtensionDeleteModel()
        if 'extension_key' in d:
            o.extension_key = d['extension_key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.YunTaskTemplateInfoDTO import YunTaskTemplateInfoDTO


class AlipayCommerceYuntaskDetailGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceYuntaskDetailGetResponse, self).__init__()
        self._task = None

    @property
    def task(self):
        return self._task

    @task.setter
    def task(self, value):
        if isinstance(value, YunTaskTemplateInfoDTO):
            self._task = value
        else:
            self._task = YunTaskTemplateInfoDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceYuntaskDetailGetResponse, self).parse_response_content(response_content)
        if 'task' in response:
            self.task = response['task']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportWorldDataSyncModel(object):

    def __init__(self):
        self._biz_data = None
        self._event_no = None
        self._event_type = None
        self._source = None
        self._sync_data = None
        self._user_id = None

    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def event_no(self):
        return self._event_no

    @event_no.setter
    def event_no(self, value):
        self._event_no = value
    @property
    def event_type(self):
        return self._event_type

    @event_type.setter
    def event_type(self, value):
        self._event_type = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def sync_data(self):
        return self._sync_data

    @sync_data.setter
    def sync_data(self, value):
        self._sync_data = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.event_no:
            if hasattr(self.event_no, 'to_alipay_dict'):
                params['event_no'] = self.event_no.to_alipay_dict()
            else:
                params['event_no'] = self.event_no
        if self.event_type:
            if hasattr(self.event_type, 'to_alipay_dict'):
                params['event_type'] = self.event_type.to_alipay_dict()
            else:
                params['event_type'] = self.event_type
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.sync_data:
            if hasattr(self.sync_data, 'to_alipay_dict'):
                params['sync_data'] = self.sync_data.to_alipay_dict()
            else:
                params['sync_data'] = self.sync_data
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportWorldDataSyncModel()
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'event_no' in d:
            o.event_no = d['event_no']
        if 'event_type' in d:
            o.event_type = d['event_type']
        if 'source' in d:
            o.source = d['source']
        if 'sync_data' in d:
            o.sync_data = d['sync_data']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoEduKtBillingQueryModel(object):

    def __init__(self):
        self._isv_pid = None
        self._out_trade_no = None
        self._school_pid = None

    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def school_pid(self):
        return self._school_pid

    @school_pid.setter
    def school_pid(self, value):
        self._school_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.school_pid:
            if hasattr(self.school_pid, 'to_alipay_dict'):
                params['school_pid'] = self.school_pid.to_alipay_dict()
            else:
                params['school_pid'] = self.school_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoEduKtBillingQueryModel()
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'school_pid' in d:
            o.school_pid = d['school_pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GovDocRequest(object):

    def __init__(self):
        self._gov_doc_request = None
        self._test = None

    @property
    def gov_doc_request(self):
        return self._gov_doc_request

    @gov_doc_request.setter
    def gov_doc_request(self, value):
        self._gov_doc_request = value
    @property
    def test(self):
        return self._test

    @test.setter
    def test(self, value):
        self._test = value


    def to_alipay_dict(self):
        params = dict()
        if self.gov_doc_request:
            if hasattr(self.gov_doc_request, 'to_alipay_dict'):
                params['gov_doc_request'] = self.gov_doc_request.to_alipay_dict()
            else:
                params['gov_doc_request'] = self.gov_doc_request
        if self.test:
            if hasattr(self.test, 'to_alipay_dict'):
                params['test'] = self.test.to_alipay_dict()
            else:
                params['test'] = self.test
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GovDocRequest()
        if 'gov_doc_request' in d:
            o.gov_doc_request = d['gov_doc_request']
        if 'test' in d:
            o.test = d['test']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZolozAuthenticationCustomerAnonymousfacesearchMatchModel(object):

    def __init__(self):
        self._antiattack = None
        self._areacode = None
        self._authimg = None
        self._biz_type = None
        self._bizscale = None
        self._brandcode = None
        self._devicenum = None
        self._extinfo = None
        self._group = None
        self._storecode = None
        self._validtimes = None

    @property
    def antiattack(self):
        return self._antiattack

    @antiattack.setter
    def antiattack(self, value):
        self._antiattack = value
    @property
    def areacode(self):
        return self._areacode

    @areacode.setter
    def areacode(self, value):
        self._areacode = value
    @property
    def authimg(self):
        return self._authimg

    @authimg.setter
    def authimg(self, value):
        self._authimg = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def bizscale(self):
        return self._bizscale

    @bizscale.setter
    def bizscale(self, value):
        self._bizscale = value
    @property
    def brandcode(self):
        return self._brandcode

    @brandcode.setter
    def brandcode(self, value):
        self._brandcode = value
    @property
    def devicenum(self):
        return self._devicenum

    @devicenum.setter
    def devicenum(self, value):
        self._devicenum = value
    @property
    def extinfo(self):
        return self._extinfo

    @extinfo.setter
    def extinfo(self, value):
        self._extinfo = value
    @property
    def group(self):
        return self._group

    @group.setter
    def group(self, value):
        self._group = value
    @property
    def storecode(self):
        return self._storecode

    @storecode.setter
    def storecode(self, value):
        self._storecode = value
    @property
    def validtimes(self):
        return self._validtimes

    @validtimes.setter
    def validtimes(self, value):
        self._validtimes = value


    def to_alipay_dict(self):
        params = dict()
        if self.antiattack:
            if hasattr(self.antiattack, 'to_alipay_dict'):
                params['antiattack'] = self.antiattack.to_alipay_dict()
            else:
                params['antiattack'] = self.antiattack
        if self.areacode:
            if hasattr(self.areacode, 'to_alipay_dict'):
                params['areacode'] = self.areacode.to_alipay_dict()
            else:
                params['areacode'] = self.areacode
        if self.authimg:
            if hasattr(self.authimg, 'to_alipay_dict'):
                params['authimg'] = self.authimg.to_alipay_dict()
            else:
                params['authimg'] = self.authimg
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.bizscale:
            if hasattr(self.bizscale, 'to_alipay_dict'):
                params['bizscale'] = self.bizscale.to_alipay_dict()
            else:
                params['bizscale'] = self.bizscale
        if self.brandcode:
            if hasattr(self.brandcode, 'to_alipay_dict'):
                params['brandcode'] = self.brandcode.to_alipay_dict()
            else:
                params['brandcode'] = self.brandcode
        if self.devicenum:
            if hasattr(self.devicenum, 'to_alipay_dict'):
                params['devicenum'] = self.devicenum.to_alipay_dict()
            else:
                params['devicenum'] = self.devicenum
        if self.extinfo:
            if hasattr(self.extinfo, 'to_alipay_dict'):
                params['extinfo'] = self.extinfo.to_alipay_dict()
            else:
                params['extinfo'] = self.extinfo
        if self.group:
            if hasattr(self.group, 'to_alipay_dict'):
                params['group'] = self.group.to_alipay_dict()
            else:
                params['group'] = self.group
        if self.storecode:
            if hasattr(self.storecode, 'to_alipay_dict'):
                params['storecode'] = self.storecode.to_alipay_dict()
            else:
                params['storecode'] = self.storecode
        if self.validtimes:
            if hasattr(self.validtimes, 'to_alipay_dict'):
                params['validtimes'] = self.validtimes.to_alipay_dict()
            else:
                params['validtimes'] = self.validtimes
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZolozAuthenticationCustomerAnonymousfacesearchMatchModel()
        if 'antiattack' in d:
            o.antiattack = d['antiattack']
        if 'areacode' in d:
            o.areacode = d['areacode']
        if 'authimg' in d:
            o.authimg = d['authimg']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'bizscale' in d:
            o.bizscale = d['bizscale']
        if 'brandcode' in d:
            o.brandcode = d['brandcode']
        if 'devicenum' in d:
            o.devicenum = d['devicenum']
        if 'extinfo' in d:
            o.extinfo = d['extinfo']
        if 'group' in d:
            o.group = d['group']
        if 'storecode' in d:
            o.storecode = d['storecode']
        if 'validtimes' in d:
            o.validtimes = d['validtimes']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BPOpenApiTask import BPOpenApiTask


class BPOpenApiInstance(object):

    def __init__(self):
        self._biz_context = None
        self._biz_id = None
        self._create_user = None
        self._description = None
        self._duration = None
        self._gmt_create = None
        self._gmt_end = None
        self._gmt_modified = None
        self._ip_role_id = None
        self._modify_user = None
        self._name = None
        self._parent_id = None
        self._parent_node = None
        self._priority = None
        self._puid = None
        self._source_id = None
        self._source_node_name = None
        self._state = None
        self._tasks = None

    @property
    def biz_context(self):
        return self._biz_context

    @biz_context.setter
    def biz_context(self, value):
        self._biz_context = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def duration(self):
        return self._duration

    @duration.setter
    def duration(self, value):
        self._duration = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def modify_user(self):
        return self._modify_user

    @modify_user.setter
    def modify_user(self, value):
        self._modify_user = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def parent_id(self):
        return self._parent_id

    @parent_id.setter
    def parent_id(self, value):
        self._parent_id = value
    @property
    def parent_node(self):
        return self._parent_node

    @parent_node.setter
    def parent_node(self, value):
        self._parent_node = value
    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        self._priority = value
    @property
    def puid(self):
        return self._puid

    @puid.setter
    def puid(self, value):
        self._puid = value
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value
    @property
    def source_node_name(self):
        return self._source_node_name

    @source_node_name.setter
    def source_node_name(self, value):
        self._source_node_name = value
    @property
    def state(self):
        return self._state

    @state.setter
    def state(self, value):
        self._state = value
    @property
    def tasks(self):
        return self._tasks

    @tasks.setter
    def tasks(self, value):
        if isinstance(value, list):
            self._tasks = list()
            for i in value:
                if isinstance(i, BPOpenApiTask):
                    self._tasks.append(i)
                else:
                    self._tasks.append(BPOpenApiTask.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.biz_context:
            if hasattr(self.biz_context, 'to_alipay_dict'):
                params['biz_context'] = self.biz_context.to_alipay_dict()
            else:
                params['biz_context'] = self.biz_context
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.duration:
            if hasattr(self.duration, 'to_alipay_dict'):
                params['duration'] = self.duration.to_alipay_dict()
            else:
                params['duration'] = self.duration
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.modify_user:
            if hasattr(self.modify_user, 'to_alipay_dict'):
                params['modify_user'] = self.modify_user.to_alipay_dict()
            else:
                params['modify_user'] = self.modify_user
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.parent_id:
            if hasattr(self.parent_id, 'to_alipay_dict'):
                params['parent_id'] = self.parent_id.to_alipay_dict()
            else:
                params['parent_id'] = self.parent_id
        if self.parent_node:
            if hasattr(self.parent_node, 'to_alipay_dict'):
                params['parent_node'] = self.parent_node.to_alipay_dict()
            else:
                params['parent_node'] = self.parent_node
        if self.priority:
            if hasattr(self.priority, 'to_alipay_dict'):
                params['priority'] = self.priority.to_alipay_dict()
            else:
                params['priority'] = self.priority
        if self.puid:
            if hasattr(self.puid, 'to_alipay_dict'):
                params['puid'] = self.puid.to_alipay_dict()
            else:
                params['puid'] = self.puid
        if self.source_id:
            if hasattr(self.source_id, 'to_alipay_dict'):
                params['source_id'] = self.source_id.to_alipay_dict()
            else:
                params['source_id'] = self.source_id
        if self.source_node_name:
            if hasattr(self.source_node_name, 'to_alipay_dict'):
                params['source_node_name'] = self.source_node_name.to_alipay_dict()
            else:
                params['source_node_name'] = self.source_node_name
        if self.state:
            if hasattr(self.state, 'to_alipay_dict'):
                params['state'] = self.state.to_alipay_dict()
            else:
                params['state'] = self.state
        if self.tasks:
            if isinstance(self.tasks, list):
                for i in range(0, len(self.tasks)):
                    element = self.tasks[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tasks[i] = element.to_alipay_dict()
            if hasattr(self.tasks, 'to_alipay_dict'):
                params['tasks'] = self.tasks.to_alipay_dict()
            else:
                params['tasks'] = self.tasks
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BPOpenApiInstance()
        if 'biz_context' in d:
            o.biz_context = d['biz_context']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'description' in d:
            o.description = d['description']
        if 'duration' in d:
            o.duration = d['duration']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'modify_user' in d:
            o.modify_user = d['modify_user']
        if 'name' in d:
            o.name = d['name']
        if 'parent_id' in d:
            o.parent_id = d['parent_id']
        if 'parent_node' in d:
            o.parent_node = d['parent_node']
        if 'priority' in d:
            o.priority = d['priority']
        if 'puid' in d:
            o.puid = d['puid']
        if 'source_id' in d:
            o.source_id = d['source_id']
        if 'source_node_name' in d:
            o.source_node_name = d['source_node_name']
        if 'state' in d:
            o.state = d['state']
        if 'tasks' in d:
            o.tasks = d['tasks']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankEcnyTradeQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankEcnyTradeQueryResponse, self).__init__()
        self._buyer_wallet_id = None
        self._buyer_wallet_name = None
        self._out_trade_no = None
        self._total_amount = None
        self._trade_no = None
        self._trade_status = None

    @property
    def buyer_wallet_id(self):
        return self._buyer_wallet_id

    @buyer_wallet_id.setter
    def buyer_wallet_id(self, value):
        self._buyer_wallet_id = value
    @property
    def buyer_wallet_name(self):
        return self._buyer_wallet_name

    @buyer_wallet_name.setter
    def buyer_wallet_name(self, value):
        self._buyer_wallet_name = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_status(self):
        return self._trade_status

    @trade_status.setter
    def trade_status(self, value):
        self._trade_status = value

    def parse_response_content(self, response_content):
        response = super(MybankEcnyTradeQueryResponse, self).parse_response_content(response_content)
        if 'buyer_wallet_id' in response:
            self.buyer_wallet_id = response['buyer_wallet_id']
        if 'buyer_wallet_name' in response:
            self.buyer_wallet_name = response['buyer_wallet_name']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']
        if 'trade_status' in response:
            self.trade_status = response['trade_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarMaintainDataUpdateModel(object):

    def __init__(self):
        self._biz_id = None
        self._event_id = None
        self._source = None
        self._type_id = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def event_id(self):
        return self._event_id

    @event_id.setter
    def event_id(self, value):
        self._event_id = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def type_id(self):
        return self._type_id

    @type_id.setter
    def type_id(self, value):
        self._type_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.event_id:
            if hasattr(self.event_id, 'to_alipay_dict'):
                params['event_id'] = self.event_id.to_alipay_dict()
            else:
                params['event_id'] = self.event_id
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.type_id:
            if hasattr(self.type_id, 'to_alipay_dict'):
                params['type_id'] = self.type_id.to_alipay_dict()
            else:
                params['type_id'] = self.type_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarMaintainDataUpdateModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'event_id' in d:
            o.event_id = d['event_id']
        if 'source' in d:
            o.source = d['source']
        if 'type_id' in d:
            o.type_id = d['type_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InvoiceItemContent(object):

    def __init__(self):
        self._item_amount = None
        self._item_name = None
        self._item_no = None
        self._item_price = None
        self._item_quantity = None
        self._item_sum_price = None
        self._item_tax_price = None
        self._item_tax_rate = None
        self._item_unit = None
        self._row_type = None

    @property
    def item_amount(self):
        return self._item_amount

    @item_amount.setter
    def item_amount(self, value):
        self._item_amount = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def item_no(self):
        return self._item_no

    @item_no.setter
    def item_no(self, value):
        self._item_no = value
    @property
    def item_price(self):
        return self._item_price

    @item_price.setter
    def item_price(self, value):
        self._item_price = value
    @property
    def item_quantity(self):
        return self._item_quantity

    @item_quantity.setter
    def item_quantity(self, value):
        self._item_quantity = value
    @property
    def item_sum_price(self):
        return self._item_sum_price

    @item_sum_price.setter
    def item_sum_price(self, value):
        self._item_sum_price = value
    @property
    def item_tax_price(self):
        return self._item_tax_price

    @item_tax_price.setter
    def item_tax_price(self, value):
        self._item_tax_price = value
    @property
    def item_tax_rate(self):
        return self._item_tax_rate

    @item_tax_rate.setter
    def item_tax_rate(self, value):
        self._item_tax_rate = value
    @property
    def item_unit(self):
        return self._item_unit

    @item_unit.setter
    def item_unit(self, value):
        self._item_unit = value
    @property
    def row_type(self):
        return self._row_type

    @row_type.setter
    def row_type(self, value):
        self._row_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.item_amount:
            if hasattr(self.item_amount, 'to_alipay_dict'):
                params['item_amount'] = self.item_amount.to_alipay_dict()
            else:
                params['item_amount'] = self.item_amount
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.item_no:
            if hasattr(self.item_no, 'to_alipay_dict'):
                params['item_no'] = self.item_no.to_alipay_dict()
            else:
                params['item_no'] = self.item_no
        if self.item_price:
            if hasattr(self.item_price, 'to_alipay_dict'):
                params['item_price'] = self.item_price.to_alipay_dict()
            else:
                params['item_price'] = self.item_price
        if self.item_quantity:
            if hasattr(self.item_quantity, 'to_alipay_dict'):
                params['item_quantity'] = self.item_quantity.to_alipay_dict()
            else:
                params['item_quantity'] = self.item_quantity
        if self.item_sum_price:
            if hasattr(self.item_sum_price, 'to_alipay_dict'):
                params['item_sum_price'] = self.item_sum_price.to_alipay_dict()
            else:
                params['item_sum_price'] = self.item_sum_price
        if self.item_tax_price:
            if hasattr(self.item_tax_price, 'to_alipay_dict'):
                params['item_tax_price'] = self.item_tax_price.to_alipay_dict()
            else:
                params['item_tax_price'] = self.item_tax_price
        if self.item_tax_rate:
            if hasattr(self.item_tax_rate, 'to_alipay_dict'):
                params['item_tax_rate'] = self.item_tax_rate.to_alipay_dict()
            else:
                params['item_tax_rate'] = self.item_tax_rate
        if self.item_unit:
            if hasattr(self.item_unit, 'to_alipay_dict'):
                params['item_unit'] = self.item_unit.to_alipay_dict()
            else:
                params['item_unit'] = self.item_unit
        if self.row_type:
            if hasattr(self.row_type, 'to_alipay_dict'):
                params['row_type'] = self.row_type.to_alipay_dict()
            else:
                params['row_type'] = self.row_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceItemContent()
        if 'item_amount' in d:
            o.item_amount = d['item_amount']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'item_no' in d:
            o.item_no = d['item_no']
        if 'item_price' in d:
            o.item_price = d['item_price']
        if 'item_quantity' in d:
            o.item_quantity = d['item_quantity']
        if 'item_sum_price' in d:
            o.item_sum_price = d['item_sum_price']
        if 'item_tax_price' in d:
            o.item_tax_price = d['item_tax_price']
        if 'item_tax_rate' in d:
            o.item_tax_rate = d['item_tax_rate']
        if 'item_unit' in d:
            o.item_unit = d['item_unit']
        if 'row_type' in d:
            o.row_type = d['row_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TradePrecreateConfirmOrderInfo(object):

    def __init__(self):
        self._body = None
        self._pay_expire_time = None
        self._quantity = None

    @property
    def body(self):
        return self._body

    @body.setter
    def body(self, value):
        self._body = value
    @property
    def pay_expire_time(self):
        return self._pay_expire_time

    @pay_expire_time.setter
    def pay_expire_time(self, value):
        self._pay_expire_time = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value


    def to_alipay_dict(self):
        params = dict()
        if self.body:
            if hasattr(self.body, 'to_alipay_dict'):
                params['body'] = self.body.to_alipay_dict()
            else:
                params['body'] = self.body
        if self.pay_expire_time:
            if hasattr(self.pay_expire_time, 'to_alipay_dict'):
                params['pay_expire_time'] = self.pay_expire_time.to_alipay_dict()
            else:
                params['pay_expire_time'] = self.pay_expire_time
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TradePrecreateConfirmOrderInfo()
        if 'body' in d:
            o.body = d['body']
        if 'pay_expire_time' in d:
            o.pay_expire_time = d['pay_expire_time']
        if 'quantity' in d:
            o.quantity = d['quantity']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.GroupInfo import GroupInfo
from alipay.aop.api.domain.MemberInfo import MemberInfo


class AlipaySocialBaseChatGroupCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialBaseChatGroupCreateResponse, self).__init__()
        self._group_info = None
        self._member_infos = None

    @property
    def group_info(self):
        return self._group_info

    @group_info.setter
    def group_info(self, value):
        if isinstance(value, GroupInfo):
            self._group_info = value
        else:
            self._group_info = GroupInfo.from_alipay_dict(value)
    @property
    def member_infos(self):
        return self._member_infos

    @member_infos.setter
    def member_infos(self, value):
        if isinstance(value, list):
            self._member_infos = list()
            for i in value:
                if isinstance(i, MemberInfo):
                    self._member_infos.append(i)
                else:
                    self._member_infos.append(MemberInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipaySocialBaseChatGroupCreateResponse, self).parse_response_content(response_content)
        if 'group_info' in response:
            self.group_info = response['group_info']
        if 'member_infos' in response:
            self.member_infos = response['member_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceTokenBatchqueryModel(object):

    def __init__(self):
        self._invoice_token = None
        self._scene = None

    @property
    def invoice_token(self):
        return self._invoice_token

    @invoice_token.setter
    def invoice_token(self, value):
        self._invoice_token = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.invoice_token:
            if hasattr(self.invoice_token, 'to_alipay_dict'):
                params['invoice_token'] = self.invoice_token.to_alipay_dict()
            else:
                params['invoice_token'] = self.invoice_token
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceTokenBatchqueryModel()
        if 'invoice_token' in d:
            o.invoice_token = d['invoice_token']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GfacConsolidationEntryLineDTO import GfacConsolidationEntryLineDTO


class AlipayBossFncGfaccenterConsolidationAcceptModel(object):

    def __init__(self):
        self._acc_month = None
        self._adjust_period = None
        self._biz_chain = None
        self._biz_date_time = None
        self._biz_event_code = None
        self._biz_module = None
        self._biz_product_code = None
        self._coa_type = None
        self._exchange_date = None
        self._exchange_rate = None
        self._exchange_type = None
        self._expect_account_date = None
        self._je_desc = None
        self._je_lines = None
        self._je_name = None
        self._je_no = None
        self._memo = None
        self._orig_currency_code = None
        self._recon_inst = None
        self._sob_currency_code = None
        self._sob_type = None
        self._src_app = None
        self._submitter = None
        self._use_user_rate_info = None

    @property
    def acc_month(self):
        return self._acc_month

    @acc_month.setter
    def acc_month(self, value):
        self._acc_month = value
    @property
    def adjust_period(self):
        return self._adjust_period

    @adjust_period.setter
    def adjust_period(self, value):
        self._adjust_period = value
    @property
    def biz_chain(self):
        return self._biz_chain

    @biz_chain.setter
    def biz_chain(self, value):
        self._biz_chain = value
    @property
    def biz_date_time(self):
        return self._biz_date_time

    @biz_date_time.setter
    def biz_date_time(self, value):
        self._biz_date_time = value
    @property
    def biz_event_code(self):
        return self._biz_event_code

    @biz_event_code.setter
    def biz_event_code(self, value):
        self._biz_event_code = value
    @property
    def biz_module(self):
        return self._biz_module

    @biz_module.setter
    def biz_module(self, value):
        self._biz_module = value
    @property
    def biz_product_code(self):
        return self._biz_product_code

    @biz_product_code.setter
    def biz_product_code(self, value):
        self._biz_product_code = value
    @property
    def coa_type(self):
        return self._coa_type

    @coa_type.setter
    def coa_type(self, value):
        self._coa_type = value
    @property
    def exchange_date(self):
        return self._exchange_date

    @exchange_date.setter
    def exchange_date(self, value):
        self._exchange_date = value
    @property
    def exchange_rate(self):
        return self._exchange_rate

    @exchange_rate.setter
    def exchange_rate(self, value):
        self._exchange_rate = value
    @property
    def exchange_type(self):
        return self._exchange_type

    @exchange_type.setter
    def exchange_type(self, value):
        self._exchange_type = value
    @property
    def expect_account_date(self):
        return self._expect_account_date

    @expect_account_date.setter
    def expect_account_date(self, value):
        self._expect_account_date = value
    @property
    def je_desc(self):
        return self._je_desc

    @je_desc.setter
    def je_desc(self, value):
        self._je_desc = value
    @property
    def je_lines(self):
        return self._je_lines

    @je_lines.setter
    def je_lines(self, value):
        if isinstance(value, list):
            self._je_lines = list()
            for i in value:
                if isinstance(i, GfacConsolidationEntryLineDTO):
                    self._je_lines.append(i)
                else:
                    self._je_lines.append(GfacConsolidationEntryLineDTO.from_alipay_dict(i))
    @property
    def je_name(self):
        return self._je_name

    @je_name.setter
    def je_name(self, value):
        self._je_name = value
    @property
    def je_no(self):
        return self._je_no

    @je_no.setter
    def je_no(self, value):
        self._je_no = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def orig_currency_code(self):
        return self._orig_currency_code

    @orig_currency_code.setter
    def orig_currency_code(self, value):
        self._orig_currency_code = value
    @property
    def recon_inst(self):
        return self._recon_inst

    @recon_inst.setter
    def recon_inst(self, value):
        self._recon_inst = value
    @property
    def sob_currency_code(self):
        return self._sob_currency_code

    @sob_currency_code.setter
    def sob_currency_code(self, value):
        self._sob_currency_code = value
    @property
    def sob_type(self):
        return self._sob_type

    @sob_type.setter
    def sob_type(self, value):
        self._sob_type = value
    @property
    def src_app(self):
        return self._src_app

    @src_app.setter
    def src_app(self, value):
        self._src_app = value
    @property
    def submitter(self):
        return self._submitter

    @submitter.setter
    def submitter(self, value):
        self._submitter = value
    @property
    def use_user_rate_info(self):
        return self._use_user_rate_info

    @use_user_rate_info.setter
    def use_user_rate_info(self, value):
        self._use_user_rate_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.acc_month:
            if hasattr(self.acc_month, 'to_alipay_dict'):
                params['acc_month'] = self.acc_month.to_alipay_dict()
            else:
                params['acc_month'] = self.acc_month
        if self.adjust_period:
            if hasattr(self.adjust_period, 'to_alipay_dict'):
                params['adjust_period'] = self.adjust_period.to_alipay_dict()
            else:
                params['adjust_period'] = self.adjust_period
        if self.biz_chain:
            if hasattr(self.biz_chain, 'to_alipay_dict'):
                params['biz_chain'] = self.biz_chain.to_alipay_dict()
            else:
                params['biz_chain'] = self.biz_chain
        if self.biz_date_time:
            if hasattr(self.biz_date_time, 'to_alipay_dict'):
                params['biz_date_time'] = self.biz_date_time.to_alipay_dict()
            else:
                params['biz_date_time'] = self.biz_date_time
        if self.biz_event_code:
            if hasattr(self.biz_event_code, 'to_alipay_dict'):
                params['biz_event_code'] = self.biz_event_code.to_alipay_dict()
            else:
                params['biz_event_code'] = self.biz_event_code
        if self.biz_module:
            if hasattr(self.biz_module, 'to_alipay_dict'):
                params['biz_module'] = self.biz_module.to_alipay_dict()
            else:
                params['biz_module'] = self.biz_module
        if self.biz_product_code:
            if hasattr(self.biz_product_code, 'to_alipay_dict'):
                params['biz_product_code'] = self.biz_product_code.to_alipay_dict()
            else:
                params['biz_product_code'] = self.biz_product_code
        if self.coa_type:
            if hasattr(self.coa_type, 'to_alipay_dict'):
                params['coa_type'] = self.coa_type.to_alipay_dict()
            else:
                params['coa_type'] = self.coa_type
        if self.exchange_date:
            if hasattr(self.exchange_date, 'to_alipay_dict'):
                params['exchange_date'] = self.exchange_date.to_alipay_dict()
            else:
                params['exchange_date'] = self.exchange_date
        if self.exchange_rate:
            if hasattr(self.exchange_rate, 'to_alipay_dict'):
                params['exchange_rate'] = self.exchange_rate.to_alipay_dict()
            else:
                params['exchange_rate'] = self.exchange_rate
        if self.exchange_type:
            if hasattr(self.exchange_type, 'to_alipay_dict'):
                params['exchange_type'] = self.exchange_type.to_alipay_dict()
            else:
                params['exchange_type'] = self.exchange_type
        if self.expect_account_date:
            if hasattr(self.expect_account_date, 'to_alipay_dict'):
                params['expect_account_date'] = self.expect_account_date.to_alipay_dict()
            else:
                params['expect_account_date'] = self.expect_account_date
        if self.je_desc:
            if hasattr(self.je_desc, 'to_alipay_dict'):
                params['je_desc'] = self.je_desc.to_alipay_dict()
            else:
                params['je_desc'] = self.je_desc
        if self.je_lines:
            if isinstance(self.je_lines, list):
                for i in range(0, len(self.je_lines)):
                    element = self.je_lines[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.je_lines[i] = element.to_alipay_dict()
            if hasattr(self.je_lines, 'to_alipay_dict'):
                params['je_lines'] = self.je_lines.to_alipay_dict()
            else:
                params['je_lines'] = self.je_lines
        if self.je_name:
            if hasattr(self.je_name, 'to_alipay_dict'):
                params['je_name'] = self.je_name.to_alipay_dict()
            else:
                params['je_name'] = self.je_name
        if self.je_no:
            if hasattr(self.je_no, 'to_alipay_dict'):
                params['je_no'] = self.je_no.to_alipay_dict()
            else:
                params['je_no'] = self.je_no
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.orig_currency_code:
            if hasattr(self.orig_currency_code, 'to_alipay_dict'):
                params['orig_currency_code'] = self.orig_currency_code.to_alipay_dict()
            else:
                params['orig_currency_code'] = self.orig_currency_code
        if self.recon_inst:
            if hasattr(self.recon_inst, 'to_alipay_dict'):
                params['recon_inst'] = self.recon_inst.to_alipay_dict()
            else:
                params['recon_inst'] = self.recon_inst
        if self.sob_currency_code:
            if hasattr(self.sob_currency_code, 'to_alipay_dict'):
                params['sob_currency_code'] = self.sob_currency_code.to_alipay_dict()
            else:
                params['sob_currency_code'] = self.sob_currency_code
        if self.sob_type:
            if hasattr(self.sob_type, 'to_alipay_dict'):
                params['sob_type'] = self.sob_type.to_alipay_dict()
            else:
                params['sob_type'] = self.sob_type
        if self.src_app:
            if hasattr(self.src_app, 'to_alipay_dict'):
                params['src_app'] = self.src_app.to_alipay_dict()
            else:
                params['src_app'] = self.src_app
        if self.submitter:
            if hasattr(self.submitter, 'to_alipay_dict'):
                params['submitter'] = self.submitter.to_alipay_dict()
            else:
                params['submitter'] = self.submitter
        if self.use_user_rate_info:
            if hasattr(self.use_user_rate_info, 'to_alipay_dict'):
                params['use_user_rate_info'] = self.use_user_rate_info.to_alipay_dict()
            else:
                params['use_user_rate_info'] = self.use_user_rate_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfaccenterConsolidationAcceptModel()
        if 'acc_month' in d:
            o.acc_month = d['acc_month']
        if 'adjust_period' in d:
            o.adjust_period = d['adjust_period']
        if 'biz_chain' in d:
            o.biz_chain = d['biz_chain']
        if 'biz_date_time' in d:
            o.biz_date_time = d['biz_date_time']
        if 'biz_event_code' in d:
            o.biz_event_code = d['biz_event_code']
        if 'biz_module' in d:
            o.biz_module = d['biz_module']
        if 'biz_product_code' in d:
            o.biz_product_code = d['biz_product_code']
        if 'coa_type' in d:
            o.coa_type = d['coa_type']
        if 'exchange_date' in d:
            o.exchange_date = d['exchange_date']
        if 'exchange_rate' in d:
            o.exchange_rate = d['exchange_rate']
        if 'exchange_type' in d:
            o.exchange_type = d['exchange_type']
        if 'expect_account_date' in d:
            o.expect_account_date = d['expect_account_date']
        if 'je_desc' in d:
            o.je_desc = d['je_desc']
        if 'je_lines' in d:
            o.je_lines = d['je_lines']
        if 'je_name' in d:
            o.je_name = d['je_name']
        if 'je_no' in d:
            o.je_no = d['je_no']
        if 'memo' in d:
            o.memo = d['memo']
        if 'orig_currency_code' in d:
            o.orig_currency_code = d['orig_currency_code']
        if 'recon_inst' in d:
            o.recon_inst = d['recon_inst']
        if 'sob_currency_code' in d:
            o.sob_currency_code = d['sob_currency_code']
        if 'sob_type' in d:
            o.sob_type = d['sob_type']
        if 'src_app' in d:
            o.src_app = d['src_app']
        if 'submitter' in d:
            o.submitter = d['submitter']
        if 'use_user_rate_info' in d:
            o.use_user_rate_info = d['use_user_rate_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MiniAppPluginReference(object):

    def __init__(self):
        self._plugin_id = None
        self._plugin_version = None

    @property
    def plugin_id(self):
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, value):
        self._plugin_id = value
    @property
    def plugin_version(self):
        return self._plugin_version

    @plugin_version.setter
    def plugin_version(self, value):
        self._plugin_version = value


    def to_alipay_dict(self):
        params = dict()
        if self.plugin_id:
            if hasattr(self.plugin_id, 'to_alipay_dict'):
                params['plugin_id'] = self.plugin_id.to_alipay_dict()
            else:
                params['plugin_id'] = self.plugin_id
        if self.plugin_version:
            if hasattr(self.plugin_version, 'to_alipay_dict'):
                params['plugin_version'] = self.plugin_version.to_alipay_dict()
            else:
                params['plugin_version'] = self.plugin_version
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MiniAppPluginReference()
        if 'plugin_id' in d:
            o.plugin_id = d['plugin_id']
        if 'plugin_version' in d:
            o.plugin_version = d['plugin_version']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ContactPersonInfo(object):

    def __init__(self):
        self._contact_email = None
        self._contact_mobile = None
        self._contact_name = None
        self._contact_type = None

    @property
    def contact_email(self):
        return self._contact_email

    @contact_email.setter
    def contact_email(self, value):
        self._contact_email = value
    @property
    def contact_mobile(self):
        return self._contact_mobile

    @contact_mobile.setter
    def contact_mobile(self, value):
        self._contact_mobile = value
    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value
    @property
    def contact_type(self):
        return self._contact_type

    @contact_type.setter
    def contact_type(self, value):
        self._contact_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.contact_email:
            if hasattr(self.contact_email, 'to_alipay_dict'):
                params['contact_email'] = self.contact_email.to_alipay_dict()
            else:
                params['contact_email'] = self.contact_email
        if self.contact_mobile:
            if hasattr(self.contact_mobile, 'to_alipay_dict'):
                params['contact_mobile'] = self.contact_mobile.to_alipay_dict()
            else:
                params['contact_mobile'] = self.contact_mobile
        if self.contact_name:
            if hasattr(self.contact_name, 'to_alipay_dict'):
                params['contact_name'] = self.contact_name.to_alipay_dict()
            else:
                params['contact_name'] = self.contact_name
        if self.contact_type:
            if hasattr(self.contact_type, 'to_alipay_dict'):
                params['contact_type'] = self.contact_type.to_alipay_dict()
            else:
                params['contact_type'] = self.contact_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ContactPersonInfo()
        if 'contact_email' in d:
            o.contact_email = d['contact_email']
        if 'contact_mobile' in d:
            o.contact_mobile = d['contact_mobile']
        if 'contact_name' in d:
            o.contact_name = d['contact_name']
        if 'contact_type' in d:
            o.contact_type = d['contact_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeskEntity import DeskEntity


class KoubeiCateringPosDeskModifyModel(object):

    def __init__(self):
        self._pos_desk = None

    @property
    def pos_desk(self):
        return self._pos_desk

    @pos_desk.setter
    def pos_desk(self, value):
        if isinstance(value, DeskEntity):
            self._pos_desk = value
        else:
            self._pos_desk = DeskEntity.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.pos_desk:
            if hasattr(self.pos_desk, 'to_alipay_dict'):
                params['pos_desk'] = self.pos_desk.to_alipay_dict()
            else:
                params['pos_desk'] = self.pos_desk
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosDeskModifyModel()
        if 'pos_desk' in d:
            o.pos_desk = d['pos_desk']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FaceAttrInfo import FaceAttrInfo


class ZolozIdentificationCustomerCertifyzhubQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZolozIdentificationCustomerCertifyzhubQueryResponse, self).__init__()
        self._attack = None
        self._biz_id = None
        self._face_attr_info = None
        self._img_str = None
        self._zim_code = None
        self._zim_msg = None
        self._zim_token = None

    @property
    def attack(self):
        return self._attack

    @attack.setter
    def attack(self, value):
        self._attack = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def face_attr_info(self):
        return self._face_attr_info

    @face_attr_info.setter
    def face_attr_info(self, value):
        if isinstance(value, FaceAttrInfo):
            self._face_attr_info = value
        else:
            self._face_attr_info = FaceAttrInfo.from_alipay_dict(value)
    @property
    def img_str(self):
        return self._img_str

    @img_str.setter
    def img_str(self, value):
        self._img_str = value
    @property
    def zim_code(self):
        return self._zim_code

    @zim_code.setter
    def zim_code(self, value):
        self._zim_code = value
    @property
    def zim_msg(self):
        return self._zim_msg

    @zim_msg.setter
    def zim_msg(self, value):
        self._zim_msg = value
    @property
    def zim_token(self):
        return self._zim_token

    @zim_token.setter
    def zim_token(self, value):
        self._zim_token = value

    def parse_response_content(self, response_content):
        response = super(ZolozIdentificationCustomerCertifyzhubQueryResponse, self).parse_response_content(response_content)
        if 'attack' in response:
            self.attack = response['attack']
        if 'biz_id' in response:
            self.biz_id = response['biz_id']
        if 'face_attr_info' in response:
            self.face_attr_info = response['face_attr_info']
        if 'img_str' in response:
            self.img_str = response['img_str']
        if 'zim_code' in response:
            self.zim_code = response['zim_code']
        if 'zim_msg' in response:
            self.zim_msg = response['zim_msg']
        if 'zim_token' in response:
            self.zim_token = response['zim_token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncGfaccruedprodCumpoaccbalamtQueryModel(object):

    def __init__(self):
        self._account_period = None
        self._po_no = None

    @property
    def account_period(self):
        return self._account_period

    @account_period.setter
    def account_period(self, value):
        self._account_period = value
    @property
    def po_no(self):
        return self._po_no

    @po_no.setter
    def po_no(self, value):
        self._po_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_period:
            if hasattr(self.account_period, 'to_alipay_dict'):
                params['account_period'] = self.account_period.to_alipay_dict()
            else:
                params['account_period'] = self.account_period
        if self.po_no:
            if hasattr(self.po_no, 'to_alipay_dict'):
                params['po_no'] = self.po_no.to_alipay_dict()
            else:
                params['po_no'] = self.po_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfaccruedprodCumpoaccbalamtQueryModel()
        if 'account_period' in d:
            o.account_period = d['account_period']
        if 'po_no' in d:
            o.po_no = d['po_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppServiceQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppServiceQueryResponse, self).__init__()
        self._reject_reason = None
        self._service_code = None
        self._service_xml = None
        self._status = None

    @property
    def reject_reason(self):
        return self._reject_reason

    @reject_reason.setter
    def reject_reason(self, value):
        self._reject_reason = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_xml(self):
        return self._service_xml

    @service_xml.setter
    def service_xml(self, value):
        self._service_xml = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppServiceQueryResponse, self).parse_response_content(response_content)
        if 'reject_reason' in response:
            self.reject_reason = response['reject_reason']
        if 'service_code' in response:
            self.service_code = response['service_code']
        if 'service_xml' in response:
            self.service_xml = response['service_xml']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniAmpeDevicemodelAddModel(object):

    def __init__(self):
        self._hardware_params = None
        self._model_name = None
        self._model_no = None
        self._product_id = None
        self._scene_code = None

    @property
    def hardware_params(self):
        return self._hardware_params

    @hardware_params.setter
    def hardware_params(self, value):
        self._hardware_params = value
    @property
    def model_name(self):
        return self._model_name

    @model_name.setter
    def model_name(self, value):
        self._model_name = value
    @property
    def model_no(self):
        return self._model_no

    @model_no.setter
    def model_no(self, value):
        self._model_no = value
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        self._product_id = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.hardware_params:
            if hasattr(self.hardware_params, 'to_alipay_dict'):
                params['hardware_params'] = self.hardware_params.to_alipay_dict()
            else:
                params['hardware_params'] = self.hardware_params
        if self.model_name:
            if hasattr(self.model_name, 'to_alipay_dict'):
                params['model_name'] = self.model_name.to_alipay_dict()
            else:
                params['model_name'] = self.model_name
        if self.model_no:
            if hasattr(self.model_no, 'to_alipay_dict'):
                params['model_no'] = self.model_no.to_alipay_dict()
            else:
                params['model_no'] = self.model_no
        if self.product_id:
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniAmpeDevicemodelAddModel()
        if 'hardware_params' in d:
            o.hardware_params = d['hardware_params']
        if 'model_name' in d:
            o.model_name = d['model_name']
        if 'model_no' in d:
            o.model_no = d['model_no']
        if 'product_id' in d:
            o.product_id = d['product_id']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInstserviceDeductUnsignResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInstserviceDeductUnsignResponse, self).__init__()
        self._error_code = None
        self._process_id = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def process_id(self):
        return self._process_id

    @process_id.setter
    def process_id(self, value):
        self._process_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInstserviceDeductUnsignResponse, self).parse_response_content(response_content)
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'process_id' in response:
            self.process_id = response['process_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InboundOrderLine(object):

    def __init__(self):
        self._batch_code = None
        self._expire_date = None
        self._goods_code = None
        self._inventory_type = None
        self._plan_quantity = None
        self._price = None
        self._product_date = None
        self._remark = None

    @property
    def batch_code(self):
        return self._batch_code

    @batch_code.setter
    def batch_code(self, value):
        self._batch_code = value
    @property
    def expire_date(self):
        return self._expire_date

    @expire_date.setter
    def expire_date(self, value):
        self._expire_date = value
    @property
    def goods_code(self):
        return self._goods_code

    @goods_code.setter
    def goods_code(self, value):
        self._goods_code = value
    @property
    def inventory_type(self):
        return self._inventory_type

    @inventory_type.setter
    def inventory_type(self, value):
        self._inventory_type = value
    @property
    def plan_quantity(self):
        return self._plan_quantity

    @plan_quantity.setter
    def plan_quantity(self, value):
        self._plan_quantity = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def product_date(self):
        return self._product_date

    @product_date.setter
    def product_date(self, value):
        self._product_date = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_code:
            if hasattr(self.batch_code, 'to_alipay_dict'):
                params['batch_code'] = self.batch_code.to_alipay_dict()
            else:
                params['batch_code'] = self.batch_code
        if self.expire_date:
            if hasattr(self.expire_date, 'to_alipay_dict'):
                params['expire_date'] = self.expire_date.to_alipay_dict()
            else:
                params['expire_date'] = self.expire_date
        if self.goods_code:
            if hasattr(self.goods_code, 'to_alipay_dict'):
                params['goods_code'] = self.goods_code.to_alipay_dict()
            else:
                params['goods_code'] = self.goods_code
        if self.inventory_type:
            if hasattr(self.inventory_type, 'to_alipay_dict'):
                params['inventory_type'] = self.inventory_type.to_alipay_dict()
            else:
                params['inventory_type'] = self.inventory_type
        if self.plan_quantity:
            if hasattr(self.plan_quantity, 'to_alipay_dict'):
                params['plan_quantity'] = self.plan_quantity.to_alipay_dict()
            else:
                params['plan_quantity'] = self.plan_quantity
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.product_date:
            if hasattr(self.product_date, 'to_alipay_dict'):
                params['product_date'] = self.product_date.to_alipay_dict()
            else:
                params['product_date'] = self.product_date
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InboundOrderLine()
        if 'batch_code' in d:
            o.batch_code = d['batch_code']
        if 'expire_date' in d:
            o.expire_date = d['expire_date']
        if 'goods_code' in d:
            o.goods_code = d['goods_code']
        if 'inventory_type' in d:
            o.inventory_type = d['inventory_type']
        if 'plan_quantity' in d:
            o.plan_quantity = d['plan_quantity']
        if 'price' in d:
            o.price = d['price']
        if 'product_date' in d:
            o.product_date = d['product_date']
        if 'remark' in d:
            o.remark = d['remark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppYufalingsanyaowubYufalingsanyaowubQueryModel(object):

    def __init__(self):
        self._yufaa = None

    @property
    def yufaa(self):
        return self._yufaa

    @yufaa.setter
    def yufaa(self, value):
        self._yufaa = value


    def to_alipay_dict(self):
        params = dict()
        if self.yufaa:
            if hasattr(self.yufaa, 'to_alipay_dict'):
                params['yufaa'] = self.yufaa.to_alipay_dict()
            else:
                params['yufaa'] = self.yufaa
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppYufalingsanyaowubYufalingsanyaowubQueryModel()
        if 'yufaa' in d:
            o.yufaa = d['yufaa']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaAuthInfoAuthqueryModel(object):

    def __init__(self):
        self._auth_category = None
        self._identity_param = None
        self._identity_type = None

    @property
    def auth_category(self):
        return self._auth_category

    @auth_category.setter
    def auth_category(self, value):
        self._auth_category = value
    @property
    def identity_param(self):
        return self._identity_param

    @identity_param.setter
    def identity_param(self, value):
        self._identity_param = value
    @property
    def identity_type(self):
        return self._identity_type

    @identity_type.setter
    def identity_type(self, value):
        self._identity_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_category:
            if hasattr(self.auth_category, 'to_alipay_dict'):
                params['auth_category'] = self.auth_category.to_alipay_dict()
            else:
                params['auth_category'] = self.auth_category
        if self.identity_param:
            if hasattr(self.identity_param, 'to_alipay_dict'):
                params['identity_param'] = self.identity_param.to_alipay_dict()
            else:
                params['identity_param'] = self.identity_param
        if self.identity_type:
            if hasattr(self.identity_type, 'to_alipay_dict'):
                params['identity_type'] = self.identity_type.to_alipay_dict()
            else:
                params['identity_type'] = self.identity_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaAuthInfoAuthqueryModel()
        if 'auth_category' in d:
            o.auth_category = d['auth_category']
        if 'identity_param' in d:
            o.identity_param = d['identity_param']
        if 'identity_type' in d:
            o.identity_type = d['identity_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IndexBigbuyItem(object):

    def __init__(self):
        self._distance = None
        self._image_url = None
        self._item_detail_url = None
        self._item_field_id = None
        self._item_id = None
        self._item_name = None
        self._item_tag = None
        self._name = None
        self._original_price = None
        self._price_unit = None
        self._selling_price = None
        self._shop_field_id = None
        self._shop_id = None
        self._shop_logo = None
        self._tb_mini_shop_id = None

    @property
    def distance(self):
        return self._distance

    @distance.setter
    def distance(self, value):
        self._distance = value
    @property
    def image_url(self):
        return self._image_url

    @image_url.setter
    def image_url(self, value):
        self._image_url = value
    @property
    def item_detail_url(self):
        return self._item_detail_url

    @item_detail_url.setter
    def item_detail_url(self, value):
        self._item_detail_url = value
    @property
    def item_field_id(self):
        return self._item_field_id

    @item_field_id.setter
    def item_field_id(self, value):
        self._item_field_id = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def item_tag(self):
        return self._item_tag

    @item_tag.setter
    def item_tag(self, value):
        self._item_tag = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def price_unit(self):
        return self._price_unit

    @price_unit.setter
    def price_unit(self, value):
        self._price_unit = value
    @property
    def selling_price(self):
        return self._selling_price

    @selling_price.setter
    def selling_price(self, value):
        self._selling_price = value
    @property
    def shop_field_id(self):
        return self._shop_field_id

    @shop_field_id.setter
    def shop_field_id(self, value):
        self._shop_field_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_logo(self):
        return self._shop_logo

    @shop_logo.setter
    def shop_logo(self, value):
        self._shop_logo = value
    @property
    def tb_mini_shop_id(self):
        return self._tb_mini_shop_id

    @tb_mini_shop_id.setter
    def tb_mini_shop_id(self, value):
        self._tb_mini_shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.distance:
            if hasattr(self.distance, 'to_alipay_dict'):
                params['distance'] = self.distance.to_alipay_dict()
            else:
                params['distance'] = self.distance
        if self.image_url:
            if hasattr(self.image_url, 'to_alipay_dict'):
                params['image_url'] = self.image_url.to_alipay_dict()
            else:
                params['image_url'] = self.image_url
        if self.item_detail_url:
            if hasattr(self.item_detail_url, 'to_alipay_dict'):
                params['item_detail_url'] = self.item_detail_url.to_alipay_dict()
            else:
                params['item_detail_url'] = self.item_detail_url
        if self.item_field_id:
            if hasattr(self.item_field_id, 'to_alipay_dict'):
                params['item_field_id'] = self.item_field_id.to_alipay_dict()
            else:
                params['item_field_id'] = self.item_field_id
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.item_tag:
            if hasattr(self.item_tag, 'to_alipay_dict'):
                params['item_tag'] = self.item_tag.to_alipay_dict()
            else:
                params['item_tag'] = self.item_tag
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.price_unit:
            if hasattr(self.price_unit, 'to_alipay_dict'):
                params['price_unit'] = self.price_unit.to_alipay_dict()
            else:
                params['price_unit'] = self.price_unit
        if self.selling_price:
            if hasattr(self.selling_price, 'to_alipay_dict'):
                params['selling_price'] = self.selling_price.to_alipay_dict()
            else:
                params['selling_price'] = self.selling_price
        if self.shop_field_id:
            if hasattr(self.shop_field_id, 'to_alipay_dict'):
                params['shop_field_id'] = self.shop_field_id.to_alipay_dict()
            else:
                params['shop_field_id'] = self.shop_field_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_logo:
            if hasattr(self.shop_logo, 'to_alipay_dict'):
                params['shop_logo'] = self.shop_logo.to_alipay_dict()
            else:
                params['shop_logo'] = self.shop_logo
        if self.tb_mini_shop_id:
            if hasattr(self.tb_mini_shop_id, 'to_alipay_dict'):
                params['tb_mini_shop_id'] = self.tb_mini_shop_id.to_alipay_dict()
            else:
                params['tb_mini_shop_id'] = self.tb_mini_shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IndexBigbuyItem()
        if 'distance' in d:
            o.distance = d['distance']
        if 'image_url' in d:
            o.image_url = d['image_url']
        if 'item_detail_url' in d:
            o.item_detail_url = d['item_detail_url']
        if 'item_field_id' in d:
            o.item_field_id = d['item_field_id']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'item_tag' in d:
            o.item_tag = d['item_tag']
        if 'name' in d:
            o.name = d['name']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'price_unit' in d:
            o.price_unit = d['price_unit']
        if 'selling_price' in d:
            o.selling_price = d['selling_price']
        if 'shop_field_id' in d:
            o.shop_field_id = d['shop_field_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_logo' in d:
            o.shop_logo = d['shop_logo']
        if 'tb_mini_shop_id' in d:
            o.tb_mini_shop_id = d['tb_mini_shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MenuAnalysisData(object):

    def __init__(self):
        self._avg_click_user_cnt = None
        self._click_cnt = None
        self._click_user_cnt = None
        self._date = None
        self._menu_type = None
        self._name = None
        self._sub_name = None

    @property
    def avg_click_user_cnt(self):
        return self._avg_click_user_cnt

    @avg_click_user_cnt.setter
    def avg_click_user_cnt(self, value):
        self._avg_click_user_cnt = value
    @property
    def click_cnt(self):
        return self._click_cnt

    @click_cnt.setter
    def click_cnt(self, value):
        self._click_cnt = value
    @property
    def click_user_cnt(self):
        return self._click_user_cnt

    @click_user_cnt.setter
    def click_user_cnt(self, value):
        self._click_user_cnt = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def menu_type(self):
        return self._menu_type

    @menu_type.setter
    def menu_type(self, value):
        self._menu_type = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def sub_name(self):
        return self._sub_name

    @sub_name.setter
    def sub_name(self, value):
        self._sub_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.avg_click_user_cnt:
            if hasattr(self.avg_click_user_cnt, 'to_alipay_dict'):
                params['avg_click_user_cnt'] = self.avg_click_user_cnt.to_alipay_dict()
            else:
                params['avg_click_user_cnt'] = self.avg_click_user_cnt
        if self.click_cnt:
            if hasattr(self.click_cnt, 'to_alipay_dict'):
                params['click_cnt'] = self.click_cnt.to_alipay_dict()
            else:
                params['click_cnt'] = self.click_cnt
        if self.click_user_cnt:
            if hasattr(self.click_user_cnt, 'to_alipay_dict'):
                params['click_user_cnt'] = self.click_user_cnt.to_alipay_dict()
            else:
                params['click_user_cnt'] = self.click_user_cnt
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.menu_type:
            if hasattr(self.menu_type, 'to_alipay_dict'):
                params['menu_type'] = self.menu_type.to_alipay_dict()
            else:
                params['menu_type'] = self.menu_type
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.sub_name:
            if hasattr(self.sub_name, 'to_alipay_dict'):
                params['sub_name'] = self.sub_name.to_alipay_dict()
            else:
                params['sub_name'] = self.sub_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MenuAnalysisData()
        if 'avg_click_user_cnt' in d:
            o.avg_click_user_cnt = d['avg_click_user_cnt']
        if 'click_cnt' in d:
            o.click_cnt = d['click_cnt']
        if 'click_user_cnt' in d:
            o.click_user_cnt = d['click_user_cnt']
        if 'date' in d:
            o.date = d['date']
        if 'menu_type' in d:
            o.menu_type = d['menu_type']
        if 'name' in d:
            o.name = d['name']
        if 'sub_name' in d:
            o.sub_name = d['sub_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeBuyerCreditApplyModel(object):

    def __init__(self):
        self._buyer_credit_source = None
        self._buyer_user_id = None
        self._credit_period = None
        self._credit_scene = None
        self._grant_credit_quota = None
        self._merchant_credit_source = None
        self._merchant_user_id = None
        self._operation_type = None
        self._out_request_no = None
        self._previous_credit_quota = None

    @property
    def buyer_credit_source(self):
        return self._buyer_credit_source

    @buyer_credit_source.setter
    def buyer_credit_source(self, value):
        self._buyer_credit_source = value
    @property
    def buyer_user_id(self):
        return self._buyer_user_id

    @buyer_user_id.setter
    def buyer_user_id(self, value):
        self._buyer_user_id = value
    @property
    def credit_period(self):
        return self._credit_period

    @credit_period.setter
    def credit_period(self, value):
        self._credit_period = value
    @property
    def credit_scene(self):
        return self._credit_scene

    @credit_scene.setter
    def credit_scene(self, value):
        self._credit_scene = value
    @property
    def grant_credit_quota(self):
        return self._grant_credit_quota

    @grant_credit_quota.setter
    def grant_credit_quota(self, value):
        self._grant_credit_quota = value
    @property
    def merchant_credit_source(self):
        return self._merchant_credit_source

    @merchant_credit_source.setter
    def merchant_credit_source(self, value):
        self._merchant_credit_source = value
    @property
    def merchant_user_id(self):
        return self._merchant_user_id

    @merchant_user_id.setter
    def merchant_user_id(self, value):
        self._merchant_user_id = value
    @property
    def operation_type(self):
        return self._operation_type

    @operation_type.setter
    def operation_type(self, value):
        self._operation_type = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def previous_credit_quota(self):
        return self._previous_credit_quota

    @previous_credit_quota.setter
    def previous_credit_quota(self, value):
        self._previous_credit_quota = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_credit_source:
            if hasattr(self.buyer_credit_source, 'to_alipay_dict'):
                params['buyer_credit_source'] = self.buyer_credit_source.to_alipay_dict()
            else:
                params['buyer_credit_source'] = self.buyer_credit_source
        if self.buyer_user_id:
            if hasattr(self.buyer_user_id, 'to_alipay_dict'):
                params['buyer_user_id'] = self.buyer_user_id.to_alipay_dict()
            else:
                params['buyer_user_id'] = self.buyer_user_id
        if self.credit_period:
            if hasattr(self.credit_period, 'to_alipay_dict'):
                params['credit_period'] = self.credit_period.to_alipay_dict()
            else:
                params['credit_period'] = self.credit_period
        if self.credit_scene:
            if hasattr(self.credit_scene, 'to_alipay_dict'):
                params['credit_scene'] = self.credit_scene.to_alipay_dict()
            else:
                params['credit_scene'] = self.credit_scene
        if self.grant_credit_quota:
            if hasattr(self.grant_credit_quota, 'to_alipay_dict'):
                params['grant_credit_quota'] = self.grant_credit_quota.to_alipay_dict()
            else:
                params['grant_credit_quota'] = self.grant_credit_quota
        if self.merchant_credit_source:
            if hasattr(self.merchant_credit_source, 'to_alipay_dict'):
                params['merchant_credit_source'] = self.merchant_credit_source.to_alipay_dict()
            else:
                params['merchant_credit_source'] = self.merchant_credit_source
        if self.merchant_user_id:
            if hasattr(self.merchant_user_id, 'to_alipay_dict'):
                params['merchant_user_id'] = self.merchant_user_id.to_alipay_dict()
            else:
                params['merchant_user_id'] = self.merchant_user_id
        if self.operation_type:
            if hasattr(self.operation_type, 'to_alipay_dict'):
                params['operation_type'] = self.operation_type.to_alipay_dict()
            else:
                params['operation_type'] = self.operation_type
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.previous_credit_quota:
            if hasattr(self.previous_credit_quota, 'to_alipay_dict'):
                params['previous_credit_quota'] = self.previous_credit_quota.to_alipay_dict()
            else:
                params['previous_credit_quota'] = self.previous_credit_quota
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeBuyerCreditApplyModel()
        if 'buyer_credit_source' in d:
            o.buyer_credit_source = d['buyer_credit_source']
        if 'buyer_user_id' in d:
            o.buyer_user_id = d['buyer_user_id']
        if 'credit_period' in d:
            o.credit_period = d['credit_period']
        if 'credit_scene' in d:
            o.credit_scene = d['credit_scene']
        if 'grant_credit_quota' in d:
            o.grant_credit_quota = d['grant_credit_quota']
        if 'merchant_credit_source' in d:
            o.merchant_credit_source = d['merchant_credit_source']
        if 'merchant_user_id' in d:
            o.merchant_user_id = d['merchant_user_id']
        if 'operation_type' in d:
            o.operation_type = d['operation_type']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'previous_credit_quota' in d:
            o.previous_credit_quota = d['previous_credit_quota']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenPublicMessageContentCreateModel(object):

    def __init__(self):
        self._benefit = None
        self._content = None
        self._could_comment = None
        self._cover = None
        self._ctype = None
        self._ext_tags = None
        self._login_ids = None
        self._title = None

    @property
    def benefit(self):
        return self._benefit

    @benefit.setter
    def benefit(self, value):
        self._benefit = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def could_comment(self):
        return self._could_comment

    @could_comment.setter
    def could_comment(self, value):
        self._could_comment = value
    @property
    def cover(self):
        return self._cover

    @cover.setter
    def cover(self, value):
        self._cover = value
    @property
    def ctype(self):
        return self._ctype

    @ctype.setter
    def ctype(self, value):
        self._ctype = value
    @property
    def ext_tags(self):
        return self._ext_tags

    @ext_tags.setter
    def ext_tags(self, value):
        self._ext_tags = value
    @property
    def login_ids(self):
        return self._login_ids

    @login_ids.setter
    def login_ids(self, value):
        self._login_ids = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit:
            if hasattr(self.benefit, 'to_alipay_dict'):
                params['benefit'] = self.benefit.to_alipay_dict()
            else:
                params['benefit'] = self.benefit
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.could_comment:
            if hasattr(self.could_comment, 'to_alipay_dict'):
                params['could_comment'] = self.could_comment.to_alipay_dict()
            else:
                params['could_comment'] = self.could_comment
        if self.cover:
            if hasattr(self.cover, 'to_alipay_dict'):
                params['cover'] = self.cover.to_alipay_dict()
            else:
                params['cover'] = self.cover
        if self.ctype:
            if hasattr(self.ctype, 'to_alipay_dict'):
                params['ctype'] = self.ctype.to_alipay_dict()
            else:
                params['ctype'] = self.ctype
        if self.ext_tags:
            if hasattr(self.ext_tags, 'to_alipay_dict'):
                params['ext_tags'] = self.ext_tags.to_alipay_dict()
            else:
                params['ext_tags'] = self.ext_tags
        if self.login_ids:
            if hasattr(self.login_ids, 'to_alipay_dict'):
                params['login_ids'] = self.login_ids.to_alipay_dict()
            else:
                params['login_ids'] = self.login_ids
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicMessageContentCreateModel()
        if 'benefit' in d:
            o.benefit = d['benefit']
        if 'content' in d:
            o.content = d['content']
        if 'could_comment' in d:
            o.could_comment = d['could_comment']
        if 'cover' in d:
            o.cover = d['cover']
        if 'ctype' in d:
            o.ctype = d['ctype']
        if 'ext_tags' in d:
            o.ext_tags = d['ext_tags']
        if 'login_ids' in d:
            o.login_ids = d['login_ids']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MerchantMemberTemplateModel import MerchantMemberTemplateModel


class KoubeiMarketingCampaignMemberTemplateBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignMemberTemplateBatchqueryResponse, self).__init__()
        self._member_templates = None

    @property
    def member_templates(self):
        return self._member_templates

    @member_templates.setter
    def member_templates(self, value):
        if isinstance(value, list):
            self._member_templates = list()
            for i in value:
                if isinstance(i, MerchantMemberTemplateModel):
                    self._member_templates.append(i)
                else:
                    self._member_templates.append(MerchantMemberTemplateModel.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignMemberTemplateBatchqueryResponse, self).parse_response_content(response_content)
        if 'member_templates' in response:
            self.member_templates = response['member_templates']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransInvoiceFromisvnotifyModifyModel(object):

    def __init__(self):
        self._area = None
        self._invoice_code = None
        self._invoice_number = None
        self._is_old_data_sync = None
        self._payer_id_type = None
        self._payer_id_value = None
        self._user_id = None

    @property
    def area(self):
        return self._area

    @area.setter
    def area(self, value):
        self._area = value
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_number(self):
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, value):
        self._invoice_number = value
    @property
    def is_old_data_sync(self):
        return self._is_old_data_sync

    @is_old_data_sync.setter
    def is_old_data_sync(self, value):
        self._is_old_data_sync = value
    @property
    def payer_id_type(self):
        return self._payer_id_type

    @payer_id_type.setter
    def payer_id_type(self, value):
        self._payer_id_type = value
    @property
    def payer_id_value(self):
        return self._payer_id_value

    @payer_id_value.setter
    def payer_id_value(self, value):
        self._payer_id_value = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.area:
            if hasattr(self.area, 'to_alipay_dict'):
                params['area'] = self.area.to_alipay_dict()
            else:
                params['area'] = self.area
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_number:
            if hasattr(self.invoice_number, 'to_alipay_dict'):
                params['invoice_number'] = self.invoice_number.to_alipay_dict()
            else:
                params['invoice_number'] = self.invoice_number
        if self.is_old_data_sync:
            if hasattr(self.is_old_data_sync, 'to_alipay_dict'):
                params['is_old_data_sync'] = self.is_old_data_sync.to_alipay_dict()
            else:
                params['is_old_data_sync'] = self.is_old_data_sync
        if self.payer_id_type:
            if hasattr(self.payer_id_type, 'to_alipay_dict'):
                params['payer_id_type'] = self.payer_id_type.to_alipay_dict()
            else:
                params['payer_id_type'] = self.payer_id_type
        if self.payer_id_value:
            if hasattr(self.payer_id_value, 'to_alipay_dict'):
                params['payer_id_value'] = self.payer_id_value.to_alipay_dict()
            else:
                params['payer_id_value'] = self.payer_id_value
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransInvoiceFromisvnotifyModifyModel()
        if 'area' in d:
            o.area = d['area']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_number' in d:
            o.invoice_number = d['invoice_number']
        if 'is_old_data_sync' in d:
            o.is_old_data_sync = d['is_old_data_sync']
        if 'payer_id_type' in d:
            o.payer_id_type = d['payer_id_type']
        if 'payer_id_value' in d:
            o.payer_id_value = d['payer_id_value']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.JfExportInstBillModel import JfExportInstBillModel


class AlipayEbppJfexportInstbillQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppJfexportInstbillQueryResponse, self).__init__()
        self._bill_key = None
        self._biz_type = None
        self._cache_key = None
        self._charge_inst = None
        self._charge_mode = None
        self._extend_field = None
        self._inst_bills = None
        self._owner_name = None
        self._sub_biz_type = None

    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def cache_key(self):
        return self._cache_key

    @cache_key.setter
    def cache_key(self, value):
        self._cache_key = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def charge_mode(self):
        return self._charge_mode

    @charge_mode.setter
    def charge_mode(self, value):
        self._charge_mode = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def inst_bills(self):
        return self._inst_bills

    @inst_bills.setter
    def inst_bills(self, value):
        if isinstance(value, list):
            self._inst_bills = list()
            for i in value:
                if isinstance(i, JfExportInstBillModel):
                    self._inst_bills.append(i)
                else:
                    self._inst_bills.append(JfExportInstBillModel.from_alipay_dict(i))
    @property
    def owner_name(self):
        return self._owner_name

    @owner_name.setter
    def owner_name(self, value):
        self._owner_name = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppJfexportInstbillQueryResponse, self).parse_response_content(response_content)
        if 'bill_key' in response:
            self.bill_key = response['bill_key']
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'cache_key' in response:
            self.cache_key = response['cache_key']
        if 'charge_inst' in response:
            self.charge_inst = response['charge_inst']
        if 'charge_mode' in response:
            self.charge_mode = response['charge_mode']
        if 'extend_field' in response:
            self.extend_field = response['extend_field']
        if 'inst_bills' in response:
            self.inst_bills = response['inst_bills']
        if 'owner_name' in response:
            self.owner_name = response['owner_name']
        if 'sub_biz_type' in response:
            self.sub_biz_type = response['sub_biz_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundStudentloanRepayQueryModel(object):

    def __init__(self):
        self._cert_no = None
        self._logon_id = None

    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        self._logon_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.logon_id:
            if hasattr(self.logon_id, 'to_alipay_dict'):
                params['logon_id'] = self.logon_id.to_alipay_dict()
            else:
                params['logon_id'] = self.logon_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundStudentloanRepayQueryModel()
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'logon_id' in d:
            o.logon_id = d['logon_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class HbMerchantBill(object):

    def __init__(self):
        self._discount_amount = None
        self._out_order_no = None
        self._period_num = None
        self._trade_amount = None
        self._trade_no = None
        self._trade_time = None

    @property
    def discount_amount(self):
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        self._discount_amount = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def period_num(self):
        return self._period_num

    @period_num.setter
    def period_num(self, value):
        self._period_num = value
    @property
    def trade_amount(self):
        return self._trade_amount

    @trade_amount.setter
    def trade_amount(self, value):
        self._trade_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_time(self):
        return self._trade_time

    @trade_time.setter
    def trade_time(self, value):
        self._trade_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.discount_amount:
            if hasattr(self.discount_amount, 'to_alipay_dict'):
                params['discount_amount'] = self.discount_amount.to_alipay_dict()
            else:
                params['discount_amount'] = self.discount_amount
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.period_num:
            if hasattr(self.period_num, 'to_alipay_dict'):
                params['period_num'] = self.period_num.to_alipay_dict()
            else:
                params['period_num'] = self.period_num
        if self.trade_amount:
            if hasattr(self.trade_amount, 'to_alipay_dict'):
                params['trade_amount'] = self.trade_amount.to_alipay_dict()
            else:
                params['trade_amount'] = self.trade_amount
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.trade_time:
            if hasattr(self.trade_time, 'to_alipay_dict'):
                params['trade_time'] = self.trade_time.to_alipay_dict()
            else:
                params['trade_time'] = self.trade_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HbMerchantBill()
        if 'discount_amount' in d:
            o.discount_amount = d['discount_amount']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'period_num' in d:
            o.period_num = d['period_num']
        if 'trade_amount' in d:
            o.trade_amount = d['trade_amount']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'trade_time' in d:
            o.trade_time = d['trade_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ConstraintInfo import ConstraintInfo
from alipay.aop.api.domain.Voucher import Voucher


class PromoItemInfo(object):

    def __init__(self):
        self._constraint_info = None
        self._id = None
        self._sale_end_time = None
        self._sale_start_time = None
        self._total_inventory = None
        self._voucher = None

    @property
    def constraint_info(self):
        return self._constraint_info

    @constraint_info.setter
    def constraint_info(self, value):
        if isinstance(value, ConstraintInfo):
            self._constraint_info = value
        else:
            self._constraint_info = ConstraintInfo.from_alipay_dict(value)
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def sale_end_time(self):
        return self._sale_end_time

    @sale_end_time.setter
    def sale_end_time(self, value):
        self._sale_end_time = value
    @property
    def sale_start_time(self):
        return self._sale_start_time

    @sale_start_time.setter
    def sale_start_time(self, value):
        self._sale_start_time = value
    @property
    def total_inventory(self):
        return self._total_inventory

    @total_inventory.setter
    def total_inventory(self, value):
        self._total_inventory = value
    @property
    def voucher(self):
        return self._voucher

    @voucher.setter
    def voucher(self, value):
        if isinstance(value, Voucher):
            self._voucher = value
        else:
            self._voucher = Voucher.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.constraint_info:
            if hasattr(self.constraint_info, 'to_alipay_dict'):
                params['constraint_info'] = self.constraint_info.to_alipay_dict()
            else:
                params['constraint_info'] = self.constraint_info
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.sale_end_time:
            if hasattr(self.sale_end_time, 'to_alipay_dict'):
                params['sale_end_time'] = self.sale_end_time.to_alipay_dict()
            else:
                params['sale_end_time'] = self.sale_end_time
        if self.sale_start_time:
            if hasattr(self.sale_start_time, 'to_alipay_dict'):
                params['sale_start_time'] = self.sale_start_time.to_alipay_dict()
            else:
                params['sale_start_time'] = self.sale_start_time
        if self.total_inventory:
            if hasattr(self.total_inventory, 'to_alipay_dict'):
                params['total_inventory'] = self.total_inventory.to_alipay_dict()
            else:
                params['total_inventory'] = self.total_inventory
        if self.voucher:
            if hasattr(self.voucher, 'to_alipay_dict'):
                params['voucher'] = self.voucher.to_alipay_dict()
            else:
                params['voucher'] = self.voucher
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PromoItemInfo()
        if 'constraint_info' in d:
            o.constraint_info = d['constraint_info']
        if 'id' in d:
            o.id = d['id']
        if 'sale_end_time' in d:
            o.sale_end_time = d['sale_end_time']
        if 'sale_start_time' in d:
            o.sale_start_time = d['sale_start_time']
        if 'total_inventory' in d:
            o.total_inventory = d['total_inventory']
        if 'voucher' in d:
            o.voucher = d['voucher']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniPublicRelationBindModel(object):

    def __init__(self):
        self._mini_app_id = None
        self._public_id = None

    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def public_id(self):
        return self._public_id

    @public_id.setter
    def public_id(self, value):
        self._public_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.public_id:
            if hasattr(self.public_id, 'to_alipay_dict'):
                params['public_id'] = self.public_id.to_alipay_dict()
            else:
                params['public_id'] = self.public_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniPublicRelationBindModel()
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'public_id' in d:
            o.public_id = d['public_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasTravelShopSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTravelShopSyncResponse, self).__init__()
        self._shop_biz_status = None
        self._sync_order_id = None
        self._sync_status = None

    @property
    def shop_biz_status(self):
        return self._shop_biz_status

    @shop_biz_status.setter
    def shop_biz_status(self, value):
        self._shop_biz_status = value
    @property
    def sync_order_id(self):
        return self._sync_order_id

    @sync_order_id.setter
    def sync_order_id(self, value):
        self._sync_order_id = value
    @property
    def sync_status(self):
        return self._sync_status

    @sync_status.setter
    def sync_status(self, value):
        self._sync_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTravelShopSyncResponse, self).parse_response_content(response_content)
        if 'shop_biz_status' in response:
            self.shop_biz_status = response['shop_biz_status']
        if 'sync_order_id' in response:
            self.sync_order_id = response['sync_order_id']
        if 'sync_status' in response:
            self.sync_status = response['sync_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CommunityRelationshipExtendField import CommunityRelationshipExtendField


class AlipayEbppCommunityRelationshipModifyModel(object):

    def __init__(self):
        self._account = None
        self._account_type = None
        self._allow_skip_pay = None
        self._billkey_url = None
        self._community_short_name = None
        self._daily_end = None
        self._daily_start = None
        self._extend_field = None
        self._out_bill_url = None
        self._service_end = None
        self._service_start = None
        self._service_type = None
        self._smid = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def allow_skip_pay(self):
        return self._allow_skip_pay

    @allow_skip_pay.setter
    def allow_skip_pay(self, value):
        self._allow_skip_pay = value
    @property
    def billkey_url(self):
        return self._billkey_url

    @billkey_url.setter
    def billkey_url(self, value):
        self._billkey_url = value
    @property
    def community_short_name(self):
        return self._community_short_name

    @community_short_name.setter
    def community_short_name(self, value):
        self._community_short_name = value
    @property
    def daily_end(self):
        return self._daily_end

    @daily_end.setter
    def daily_end(self, value):
        self._daily_end = value
    @property
    def daily_start(self):
        return self._daily_start

    @daily_start.setter
    def daily_start(self, value):
        self._daily_start = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        if isinstance(value, CommunityRelationshipExtendField):
            self._extend_field = value
        else:
            self._extend_field = CommunityRelationshipExtendField.from_alipay_dict(value)
    @property
    def out_bill_url(self):
        return self._out_bill_url

    @out_bill_url.setter
    def out_bill_url(self, value):
        self._out_bill_url = value
    @property
    def service_end(self):
        return self._service_end

    @service_end.setter
    def service_end(self, value):
        self._service_end = value
    @property
    def service_start(self):
        return self._service_start

    @service_start.setter
    def service_start(self, value):
        self._service_start = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.allow_skip_pay:
            if hasattr(self.allow_skip_pay, 'to_alipay_dict'):
                params['allow_skip_pay'] = self.allow_skip_pay.to_alipay_dict()
            else:
                params['allow_skip_pay'] = self.allow_skip_pay
        if self.billkey_url:
            if hasattr(self.billkey_url, 'to_alipay_dict'):
                params['billkey_url'] = self.billkey_url.to_alipay_dict()
            else:
                params['billkey_url'] = self.billkey_url
        if self.community_short_name:
            if hasattr(self.community_short_name, 'to_alipay_dict'):
                params['community_short_name'] = self.community_short_name.to_alipay_dict()
            else:
                params['community_short_name'] = self.community_short_name
        if self.daily_end:
            if hasattr(self.daily_end, 'to_alipay_dict'):
                params['daily_end'] = self.daily_end.to_alipay_dict()
            else:
                params['daily_end'] = self.daily_end
        if self.daily_start:
            if hasattr(self.daily_start, 'to_alipay_dict'):
                params['daily_start'] = self.daily_start.to_alipay_dict()
            else:
                params['daily_start'] = self.daily_start
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = self.extend_field.to_alipay_dict()
            else:
                params['extend_field'] = self.extend_field
        if self.out_bill_url:
            if hasattr(self.out_bill_url, 'to_alipay_dict'):
                params['out_bill_url'] = self.out_bill_url.to_alipay_dict()
            else:
                params['out_bill_url'] = self.out_bill_url
        if self.service_end:
            if hasattr(self.service_end, 'to_alipay_dict'):
                params['service_end'] = self.service_end.to_alipay_dict()
            else:
                params['service_end'] = self.service_end
        if self.service_start:
            if hasattr(self.service_start, 'to_alipay_dict'):
                params['service_start'] = self.service_start.to_alipay_dict()
            else:
                params['service_start'] = self.service_start
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppCommunityRelationshipModifyModel()
        if 'account' in d:
            o.account = d['account']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'allow_skip_pay' in d:
            o.allow_skip_pay = d['allow_skip_pay']
        if 'billkey_url' in d:
            o.billkey_url = d['billkey_url']
        if 'community_short_name' in d:
            o.community_short_name = d['community_short_name']
        if 'daily_end' in d:
            o.daily_end = d['daily_end']
        if 'daily_start' in d:
            o.daily_start = d['daily_start']
        if 'extend_field' in d:
            o.extend_field = d['extend_field']
        if 'out_bill_url' in d:
            o.out_bill_url = d['out_bill_url']
        if 'service_end' in d:
            o.service_end = d['service_end']
        if 'service_start' in d:
            o.service_start = d['service_start']
        if 'service_type' in d:
            o.service_type = d['service_type']
        if 'smid' in d:
            o.smid = d['smid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MStepCashRule(object):

    def __init__(self):
        self._reduction_amount = None
        self._threshold_amount = None

    @property
    def reduction_amount(self):
        return self._reduction_amount

    @reduction_amount.setter
    def reduction_amount(self, value):
        self._reduction_amount = value
    @property
    def threshold_amount(self):
        return self._threshold_amount

    @threshold_amount.setter
    def threshold_amount(self, value):
        self._threshold_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.reduction_amount:
            if hasattr(self.reduction_amount, 'to_alipay_dict'):
                params['reduction_amount'] = self.reduction_amount.to_alipay_dict()
            else:
                params['reduction_amount'] = self.reduction_amount
        if self.threshold_amount:
            if hasattr(self.threshold_amount, 'to_alipay_dict'):
                params['threshold_amount'] = self.threshold_amount.to_alipay_dict()
            else:
                params['threshold_amount'] = self.threshold_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MStepCashRule()
        if 'reduction_amount' in d:
            o.reduction_amount = d['reduction_amount']
        if 'threshold_amount' in d:
            o.threshold_amount = d['threshold_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenApiResponseHeader(object):

    def __init__(self):
        self._conversation_id = None
        self._response_id = None
        self._status_code = None
        self._status_message = None
        self._sub_status_code = None

    @property
    def conversation_id(self):
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, value):
        self._conversation_id = value
    @property
    def response_id(self):
        return self._response_id

    @response_id.setter
    def response_id(self, value):
        self._response_id = value
    @property
    def status_code(self):
        return self._status_code

    @status_code.setter
    def status_code(self, value):
        self._status_code = value
    @property
    def status_message(self):
        return self._status_message

    @status_message.setter
    def status_message(self, value):
        self._status_message = value
    @property
    def sub_status_code(self):
        return self._sub_status_code

    @sub_status_code.setter
    def sub_status_code(self, value):
        self._sub_status_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.conversation_id:
            if hasattr(self.conversation_id, 'to_alipay_dict'):
                params['conversation_id'] = self.conversation_id.to_alipay_dict()
            else:
                params['conversation_id'] = self.conversation_id
        if self.response_id:
            if hasattr(self.response_id, 'to_alipay_dict'):
                params['response_id'] = self.response_id.to_alipay_dict()
            else:
                params['response_id'] = self.response_id
        if self.status_code:
            if hasattr(self.status_code, 'to_alipay_dict'):
                params['status_code'] = self.status_code.to_alipay_dict()
            else:
                params['status_code'] = self.status_code
        if self.status_message:
            if hasattr(self.status_message, 'to_alipay_dict'):
                params['status_message'] = self.status_message.to_alipay_dict()
            else:
                params['status_message'] = self.status_message
        if self.sub_status_code:
            if hasattr(self.sub_status_code, 'to_alipay_dict'):
                params['sub_status_code'] = self.sub_status_code.to_alipay_dict()
            else:
                params['sub_status_code'] = self.sub_status_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenApiResponseHeader()
        if 'conversation_id' in d:
            o.conversation_id = d['conversation_id']
        if 'response_id' in d:
            o.response_id = d['response_id']
        if 'status_code' in d:
            o.status_code = d['status_code']
        if 'status_message' in d:
            o.status_message = d['status_message']
        if 'sub_status_code' in d:
            o.sub_status_code = d['sub_status_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CommodityInfoList import CommodityInfoList


class AlipayFinancialnetAuthCommoditySyncModel(object):

    def __init__(self):
        self._commodity_infos = None
        self._out_order_no = None
        self._platform_id = None

    @property
    def commodity_infos(self):
        return self._commodity_infos

    @commodity_infos.setter
    def commodity_infos(self, value):
        if isinstance(value, list):
            self._commodity_infos = list()
            for i in value:
                if isinstance(i, CommodityInfoList):
                    self._commodity_infos.append(i)
                else:
                    self._commodity_infos.append(CommodityInfoList.from_alipay_dict(i))
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def platform_id(self):
        return self._platform_id

    @platform_id.setter
    def platform_id(self, value):
        self._platform_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.commodity_infos:
            if isinstance(self.commodity_infos, list):
                for i in range(0, len(self.commodity_infos)):
                    element = self.commodity_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.commodity_infos[i] = element.to_alipay_dict()
            if hasattr(self.commodity_infos, 'to_alipay_dict'):
                params['commodity_infos'] = self.commodity_infos.to_alipay_dict()
            else:
                params['commodity_infos'] = self.commodity_infos
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.platform_id:
            if hasattr(self.platform_id, 'to_alipay_dict'):
                params['platform_id'] = self.platform_id.to_alipay_dict()
            else:
                params['platform_id'] = self.platform_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFinancialnetAuthCommoditySyncModel()
        if 'commodity_infos' in d:
            o.commodity_infos = d['commodity_infos']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'platform_id' in d:
            o.platform_id = d['platform_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TemplateImageDTO(object):

    def __init__(self):
        self._logo = None
        self._strip = None

    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def strip(self):
        return self._strip

    @strip.setter
    def strip(self, value):
        self._strip = value


    def to_alipay_dict(self):
        params = dict()
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.strip:
            if hasattr(self.strip, 'to_alipay_dict'):
                params['strip'] = self.strip.to_alipay_dict()
            else:
                params['strip'] = self.strip
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TemplateImageDTO()
        if 'logo' in d:
            o.logo = d['logo']
        if 'strip' in d:
            o.strip = d['strip']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppDetectReportQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppDetectReportQueryResponse, self).__init__()
        self._audit_done = None
        self._audit_pass = None
        self._detail_report = None
        self._detect_detail = None
        self._detect_result = None
        self._detect_result_detail_list = None
        self._detect_status = None
        self._err_msg = None
        self._out_biz_no = None
        self._pass = None
        self._summary = None

    @property
    def audit_done(self):
        return self._audit_done

    @audit_done.setter
    def audit_done(self, value):
        self._audit_done = value
    @property
    def audit_pass(self):
        return self._audit_pass

    @audit_pass.setter
    def audit_pass(self, value):
        self._audit_pass = value
    @property
    def detail_report(self):
        return self._detail_report

    @detail_report.setter
    def detail_report(self, value):
        self._detail_report = value
    @property
    def detect_detail(self):
        return self._detect_detail

    @detect_detail.setter
    def detect_detail(self, value):
        self._detect_detail = value
    @property
    def detect_result(self):
        return self._detect_result

    @detect_result.setter
    def detect_result(self, value):
        self._detect_result = value
    @property
    def detect_result_detail_list(self):
        return self._detect_result_detail_list

    @detect_result_detail_list.setter
    def detect_result_detail_list(self, value):
        if isinstance(value, list):
            self._detect_result_detail_list = list()
            for i in value:
                self._detect_result_detail_list.append(i)
    @property
    def detect_status(self):
        return self._detect_status

    @detect_status.setter
    def detect_status(self, value):
        self._detect_status = value
    @property
    def err_msg(self):
        return self._err_msg

    @err_msg.setter
    def err_msg(self, value):
        self._err_msg = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def pass(self):
        return self._pass

    @pass.setter
    def pass(self, value):
        self._pass = value
    @property
    def summary(self):
        return self._summary

    @summary.setter
    def summary(self, value):
        self._summary = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppDetectReportQueryResponse, self).parse_response_content(response_content)
        if 'audit_done' in response:
            self.audit_done = response['audit_done']
        if 'audit_pass' in response:
            self.audit_pass = response['audit_pass']
        if 'detail_report' in response:
            self.detail_report = response['detail_report']
        if 'detect_detail' in response:
            self.detect_detail = response['detect_detail']
        if 'detect_result' in response:
            self.detect_result = response['detect_result']
        if 'detect_result_detail_list' in response:
            self.detect_result_detail_list = response['detect_result_detail_list']
        if 'detect_status' in response:
            self.detect_status = response['detect_status']
        if 'err_msg' in response:
            self.err_msg = response['err_msg']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'pass' in response:
            self.pass = response['pass']
        if 'summary' in response:
            self.summary = response['summary']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BizAbilityData(object):

    def __init__(self):
        self._data = None
        self._key = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value


    def to_alipay_dict(self):
        params = dict()
        if self.data:
            if hasattr(self.data, 'to_alipay_dict'):
                params['data'] = self.data.to_alipay_dict()
            else:
                params['data'] = self.data
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BizAbilityData()
        if 'data' in d:
            o.data = d['data']
        if 'key' in d:
            o.key = d['key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CaseInfoCode import CaseInfoCode


class AlipayInsDataAutoFraudQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsDataAutoFraudQueryResponse, self).__init__()
        self._fraud_tag = None
        self._fraud_tag_level = None
        self._info_code_list = None

    @property
    def fraud_tag(self):
        return self._fraud_tag

    @fraud_tag.setter
    def fraud_tag(self, value):
        self._fraud_tag = value
    @property
    def fraud_tag_level(self):
        return self._fraud_tag_level

    @fraud_tag_level.setter
    def fraud_tag_level(self, value):
        self._fraud_tag_level = value
    @property
    def info_code_list(self):
        return self._info_code_list

    @info_code_list.setter
    def info_code_list(self, value):
        if isinstance(value, list):
            self._info_code_list = list()
            for i in value:
                if isinstance(i, CaseInfoCode):
                    self._info_code_list.append(i)
                else:
                    self._info_code_list.append(CaseInfoCode.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayInsDataAutoFraudQueryResponse, self).parse_response_content(response_content)
        if 'fraud_tag' in response:
            self.fraud_tag = response['fraud_tag']
        if 'fraud_tag_level' in response:
            self.fraud_tag_level = response['fraud_tag_level']
        if 'info_code_list' in response:
            self.info_code_list = response['info_code_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BankcardExtInfo import BankcardExtInfo


class Participant(object):

    def __init__(self):
        self._bankcard_ext_info = None
        self._ext_info = None
        self._identity = None
        self._identity_type = None
        self._merchant_user_info = None
        self._name = None

    @property
    def bankcard_ext_info(self):
        return self._bankcard_ext_info

    @bankcard_ext_info.setter
    def bankcard_ext_info(self, value):
        if isinstance(value, BankcardExtInfo):
            self._bankcard_ext_info = value
        else:
            self._bankcard_ext_info = BankcardExtInfo.from_alipay_dict(value)
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def identity(self):
        return self._identity

    @identity.setter
    def identity(self, value):
        self._identity = value
    @property
    def identity_type(self):
        return self._identity_type

    @identity_type.setter
    def identity_type(self, value):
        self._identity_type = value
    @property
    def merchant_user_info(self):
        return self._merchant_user_info

    @merchant_user_info.setter
    def merchant_user_info(self, value):
        self._merchant_user_info = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.bankcard_ext_info:
            if hasattr(self.bankcard_ext_info, 'to_alipay_dict'):
                params['bankcard_ext_info'] = self.bankcard_ext_info.to_alipay_dict()
            else:
                params['bankcard_ext_info'] = self.bankcard_ext_info
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.identity:
            if hasattr(self.identity, 'to_alipay_dict'):
                params['identity'] = self.identity.to_alipay_dict()
            else:
                params['identity'] = self.identity
        if self.identity_type:
            if hasattr(self.identity_type, 'to_alipay_dict'):
                params['identity_type'] = self.identity_type.to_alipay_dict()
            else:
                params['identity_type'] = self.identity_type
        if self.merchant_user_info:
            if hasattr(self.merchant_user_info, 'to_alipay_dict'):
                params['merchant_user_info'] = self.merchant_user_info.to_alipay_dict()
            else:
                params['merchant_user_info'] = self.merchant_user_info
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Participant()
        if 'bankcard_ext_info' in d:
            o.bankcard_ext_info = d['bankcard_ext_info']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'identity' in d:
            o.identity = d['identity']
        if 'identity_type' in d:
            o.identity_type = d['identity_type']
        if 'merchant_user_info' in d:
            o.merchant_user_info = d['merchant_user_info']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOfflineMarketShopQuerydetailModel(object):

    def __init__(self):
        self._op_role = None
        self._shop_id = None

    @property
    def op_role(self):
        return self._op_role

    @op_role.setter
    def op_role(self, value):
        self._op_role = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.op_role:
            if hasattr(self.op_role, 'to_alipay_dict'):
                params['op_role'] = self.op_role.to_alipay_dict()
            else:
                params['op_role'] = self.op_role
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOfflineMarketShopQuerydetailModel()
        if 'op_role' in d:
            o.op_role = d['op_role']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o


